
# Type: manifestation of


used in SemMedDB for linking things like dysfunctions and processes to some disease or syndrome

URI: [biolink:manifestation_of](https://w3id.org/biolink/vocab/manifestation_of)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [Disease](Disease.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | SEMMEDDB:MANIFESTATION_OF |
|  | | WD:P1557 |
| **In Subsets:** | | translator_minimal |

